@@ -23,13 +23,11 @@ class BaseQuery(object):
     return self.name
 
   def __init__(self, **kwargs):
-    print kwargs
     self.connector = connectors['postgres']()
     if kwargs['db'] in dbs.keys():
       self.connector = connectors[dbs[kwargs['db']]['type']]()
 
     for k in required:
-      print k
       self.__setattr__(k, kwargs[k])
       self.connector.__setattr__(k, kwargs[k])
 
