@@ -1,11 +1,9 @@
 #!/usr/bin/env python
 
-import os
-import json
-import inspect
-import imp
 
 import sys
+import os
+from pipeables import queries
 
 #the base query all queries inherit from
 from base import BaseQuery
@@ -15,22 +13,6 @@ from os.path import expanduser
 home = expanduser("~")
 
 
-required_properties = ['proj','name','q','params','db']
-queries = {}
-sys.path.append(home+"/.pipeables")
-for f in os.listdir(home+"/.pipeables"):
-  if f.endswith(".py") and f != '__init__.py':
-    m = f.replace(".py","")
-    a,b,c = imp.find_module(m)
-    t = imp.load_module(m,a,b,c)
-    for k,v in t.__dict__.iteritems():
-      if inspect.isclass(v):
-        keys = map(lambda x: x[0], inspect.getmembers(v))
-        if len(required_properties) == len(set(keys) & set(required_properties)):
-          if v.proj not in queries.keys():
-            queries[v.proj] = {}
-          queries[v.proj][v.name] = v
-
 
 
 
